@@ -429,6 +429,11 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
         data: T.List[T.Dict[str, T.Any]] = []
         for insert in inserts:
             d = insert.dict(exclude_none=True)
+            # if the cast says they should be strings and they are not, turn them into json
+            for field_name, value in d.items():
+                if cast := cls._edgedb_conversion_map.get(field_name, {}).get("cast"):
+                    if cast.endswith("::str") and not isinstance(value, str):
+                        d[field_name] = json.dumps(jsonable_encoder(value))
             # get fields that are LINKS
             for link_name in cls._link_conversion_map.keys():
                 if link_resolver := getattr(insert, link_name, None):
